@@ -4,7 +4,7 @@
 
 ;; Maintainer: Nicolas P. Rougier <Nicolas.Rougier@inria.fr>
 ;; URL: https://github.com/rougier/nano-modeline
-;; Version: 1.0.0
+;; Version: 1.0.1
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mode-line, header-line
 
@@ -39,9 +39,31 @@
 ;; Make text mode modeline the default:
 ;; (nano-modeline-text-mode t)
 ;;
+;; Install all available modes:
+;; (add-hook 'prog-mode-hook            #'nano-modeline-prog-mode)
+;; (add-hook 'text-mode-hook            #'nano-modeline-text-mode)
+;; (add-hook 'org-mode-hook             #'nano-modeline-org-mode)
+;; (add-hook 'pdf-view-mode-hook        #'nano-modeline-pdf-mode)
+;; (add-hook 'mu4e-headers-mode-hook    #'nano-modeline-mu4e-headers-mode)
+;; (add-hook 'mu4e-view-mode-hook       #'nano-modeline-mu4e-message-mode)
+;; (add-hook 'mu4e-compose-mode-hook    #'nano-modeline-mu4e-compose-mode)
+;; (add-hook 'elfeed-show-mode-hook     #'nano-modeline-elfeed-entry-mode)
+;; (add-hook 'elfeed-search-mode-hook   #'nano-modeline-elfeed-search-mode)
+;; (add-hook 'elpher-mode-hook          #'nano-modeline-elpher-mode)
+;; (add-hook 'term-mode-hook            #'nano-modeline-term-mode)
+;; (add-hook 'eat-mode-hook             #'nano-modeline-eat-mode)
+;; (add-hook 'xwidget-webkit-mode-hook  #'nano-modeline-xwidget-mode)
+;; (add-hook 'messages-buffer-mode-hook #'nano-modeline-message-mode)
+;; (add-hook 'org-capture-mode-hook     #'nano-modeline-org-capture-mode)
+;; (add-hook 'org-agenda-mode-hook      #'nano-modeline-org-agenda-mode)
+;;
 ;;
 ;;; NEWS:
 ;;
+;;
+;; Version 1.0.1
+;; - Minor bugfix
+;;
 ;; Version 1.0.0
 ;; - Complete rewrite to make it simpler & faster
 ;; - API break: No longer a minor mode
@@ -145,7 +167,7 @@
   "Active button face")
 
 (defface nano-modeline-button-inactive-face
-  `((t :foreground ,(face-foreground (when (facep 'nano-faded) 'nano-faded 'default))
+  `((t :foreground ,(face-foreground (if (facep 'nano-faded) 'nano-faded 'default))
        :background ,(face-background 'header-line nil t)
        :family "Roboto Mono"
        :box (:line-width 2
@@ -620,7 +642,8 @@ delay needs to be set to 0."
 (defun nano-modeline-elfeed-entry-title ()
   "Elfeed entry title"
   
-  (let* ((title (elfeed-entry-title elfeed-show-entry)))
+  (let* ((title (elfeed-entry-title elfeed-show-entry))
+         (title (string-replace "%" "%%" title)))
     (propertize title 'face (nano-modeline-face 'name))))
 
 (defun nano-modeline-elfeed-search-filter ()
@@ -874,7 +897,7 @@ common action"
              (nano-modeline-window-dedicated))))
 
 (defun nano-modeline-eat-mode ()
-  "Nano line for term mode"
+  "Nano line for term (eat) mode"
 
   (funcall nano-modeline-position
            '((nano-modeline-buffer-status ">_") " "
@@ -913,7 +936,7 @@ common action"
                (nano-modeline-window-dedicated)))))
 
 (defun nano-modeline-org-agenda-mode ()
-  "Nano line for org capture mode"
+  "Nano line for org agenda mode"
 
   (add-hook 'post-command-hook #'force-mode-line-update)
   (funcall nano-modeline-position
